@@ -1,13 +1,16 @@
+from unittest.mock import patch
 from django.test import TestCase, override_settings
 from django.urls import reverse
 from django.contrib.messages import get_messages
 from django.db.models import Sum
+from django.core.cache import cache
 
 from allianceauth.tests.auth_utils import AuthUtils
 from allianceauth.authentication.models import CharacterOwnership
 from allianceauth.eveonline.models import EveCharacter
 
 from ..models import Rotation, Entry, EntryCharacter, EntryRole
+from ..views import RUNNING_AVERAGES_CACHE_PREFIX
 
 
 class TestIndexView(TestCase):
@@ -42,6 +45,16 @@ class TestDashboardView(TestCase):
 
         self.assertTemplateUsed(response, 'allianceauth_pve/ratting-dashboard.html')
 
+        self.assertTrue(cache.has_key(f"{RUNNING_AVERAGES_CACHE_PREFIX}_{self.testuser.pk}_30"))
+        self.assertTrue(cache.has_key(f"{RUNNING_AVERAGES_CACHE_PREFIX}_{self.testuser.pk}_90"))
+        self.assertTrue(cache.has_key(f"{RUNNING_AVERAGES_CACHE_PREFIX}_{self.testuser.pk}_180"))
+        self.assertTrue(cache.has_key(f"{RUNNING_AVERAGES_CACHE_PREFIX}_{self.testuser.pk}_365"))
+
+        with patch('allianceauth_pve.views.running_averages') as mock_running_average:
+            response = self.client.get(reverse('allianceauth_pve:dashboard'))
+
+            self.assertFalse(mock_running_average.called)
+
 
 class TestRotationView(TestCase):
 
@@ -188,6 +201,8 @@ class TestGetAvaiableRatters(TestCase):
                         'user_id': self.testuser.pk,
                         'user_main_character_name': self.testcharacter.character_name,
                         'user_pic': self.testcharacter.portrait_url_32,
+                        'char_status': 'Main',
+                        'char_tooltip': '',
                     },
                     {
                         'character_id': self.testcharacter2.pk,
@@ -196,6 +211,8 @@ class TestGetAvaiableRatters(TestCase):
                         'user_id': self.testuser2.pk,
                         'user_main_character_name': self.testcharacter2.character_name,
                         'user_pic': self.testcharacter2.portrait_url_32,
+                        'char_status': 'Main',
+                        'char_tooltip': '',
                     }
                 ]
             }
@@ -218,6 +235,8 @@ class TestGetAvaiableRatters(TestCase):
                         'user_id': self.testuser2.pk,
                         'user_main_character_name': self.testcharacter2.character_name,
                         'user_pic': self.testcharacter2.portrait_url_32,
+                        'char_status': 'Main',
+                        'char_tooltip': '',
                     }
                 ]
             }
@@ -240,6 +259,8 @@ class TestGetAvaiableRatters(TestCase):
                         'user_id': self.testuser2.pk,
                         'user_main_character_name': self.testcharacter2.character_name,
                         'user_pic': self.testcharacter2.portrait_url_32,
+                        'char_status': 'Main',
+                        'char_tooltip': '',
                     }
                 ]
             }
@@ -284,6 +305,8 @@ class TestGetAvaiableRatters(TestCase):
                         'user_id': self.testuser2.pk,
                         'user_main_character_name': self.testcharacter2.character_name,
                         'user_pic': self.testcharacter2.portrait_url_32,
+                        'char_status': 'Main',
+                        'char_tooltip': testcharacter2bis.character_name,
                     }
                 ]
             }
@@ -332,6 +355,8 @@ class TestGetAvaiableRatters(TestCase):
                         'user_id': self.testuser2.pk,
                         'user_main_character_name': self.testcharacter2.character_name,
                         'user_pic': self.testcharacter2.portrait_url_32,
+                        'char_status': 'Main',
+                        'char_tooltip': f'{testcharacter2bis.character_name}, {testcharacter2tris.character_name}',
                     },
                     {
                         'character_id': testcharacter2bis.pk,
@@ -340,6 +365,8 @@ class TestGetAvaiableRatters(TestCase):
                         'user_id': self.testuser2.pk,
                         'user_main_character_name': self.testcharacter2.character_name,
                         'user_pic': self.testcharacter2.portrait_url_32,
+                        'char_status': 'Alt',
+                        'char_tooltip': self.testcharacter2.character_name,
                     }
                 ]
             }
@@ -527,7 +554,7 @@ class TestAddEntryView(TestCase):
 
         self.assertEqual(entry.ratting_shares.count(), 2)
 
-        estimated_total = entry.ratting_shares.aggregate(val=Sum('estimated_share_total'))['val']
+        estimated_total = entry.ratting_shares.with_totals().aggregate(val=Sum('estimated_share_total'))['val']
         self.assertAlmostEqual(estimated_total, 1660200000.0)
         self.assertAlmostEqual(estimated_total, entry.estimated_total)
 
@@ -577,7 +604,7 @@ class TestAddEntryView(TestCase):
 
         self.assertEqual(self.entry.ratting_shares.count(), 2)
 
-        estimated_total = self.entry.ratting_shares.aggregate(val=Sum('estimated_share_total'))['val']
+        estimated_total = self.entry.ratting_shares.with_totals().aggregate(val=Sum('estimated_share_total'))['val']
         self.assertAlmostEqual(estimated_total, 1660200000.0)
         self.assertAlmostEqual(estimated_total, self.entry.estimated_total)
 
