@@ -1,5 +1,4 @@
 import datetime
-import re
 
 from django.http import JsonResponse
 from django.shortcuts import render, redirect, get_object_or_404
@@ -13,6 +12,7 @@ from django.db.models import F, Q, Count, Exists, OuterRef
 from django.db import transaction
 from django.views.generic.detail import DetailView
 from django.conf import settings
+from django.core.cache import cache
 
 from allianceauth.services.hooks import get_extension_logger
 from allianceauth.authentication.models import CharacterOwnership
@@ -24,6 +24,10 @@ from .actions import running_averages, check_forms_valid
 logger = get_extension_logger(__name__)
 
 
+RUNNING_AVERAGES_CACHE_PREFIX = 'pve_running_averages'
+RUNNING_AVERAGES_CACHE_TIMEOUT = 60 * 60
+
+
 @login_required
 @permission_required('allianceauth_pve.access_pve')
 def index(request):
@@ -44,10 +48,27 @@ def dashboard(request):
 
     today = timezone.now().date()
 
-    one_month_average = running_averages(request.user, today - datetime.timedelta(days=30))
-    three_month_average = running_averages(request.user, today - datetime.timedelta(days=30 * 3))
-    six_month_average = running_averages(request.user, today - datetime.timedelta(days=30 * 6))
-    one_year_average = running_averages(request.user, today - datetime.timedelta(days=30 * 12))
+    key_prefix = f"{RUNNING_AVERAGES_CACHE_PREFIX}_{request.user.pk}"
+
+    one_month_average = cache.get(f"{key_prefix}_30")
+    if one_month_average is None:
+        one_month_average = running_averages(request.user, today - datetime.timedelta(days=30))
+        cache.set(f"{key_prefix}_30", one_month_average, RUNNING_AVERAGES_CACHE_TIMEOUT)
+
+    three_month_average = cache.get(f"{key_prefix}_90")
+    if three_month_average is None:
+        three_month_average = running_averages(request.user, today - datetime.timedelta(days=30 * 3))
+        cache.set(f"{key_prefix}_90", three_month_average, RUNNING_AVERAGES_CACHE_TIMEOUT)
+
+    six_month_average = cache.get(f"{key_prefix}_180")
+    if six_month_average is None:
+        six_month_average = running_averages(request.user, today - datetime.timedelta(days=30 * 6))
+        cache.set(f"{key_prefix}_180", six_month_average, RUNNING_AVERAGES_CACHE_TIMEOUT)
+
+    one_year_average = cache.get(f"{key_prefix}_365")
+    if one_year_average is None:
+        one_year_average = running_averages(request.user, today - datetime.timedelta(days=30 * 12))
+        cache.set(f"{key_prefix}_365", one_year_average, RUNNING_AVERAGES_CACHE_TIMEOUT)
 
     context = {
         'open_count': open_rots.count(),
@@ -78,8 +99,6 @@ def rotation_view(request, rotation_id):
                 r.is_closed = True
                 r.closed_at = timezone.now()
                 r.save()
-                for entry in r.entries.all():
-                    entry.update_share_totals()
 
             closeform = None
     elif not r.is_closed:
@@ -148,7 +167,9 @@ def get_avaiable_ratters(request, name=None):
                 'user_id': ownership.user_id,
                 'user_main_character_name': ownership.user.profile.main_character.character_name,
                 'user_pic': ownership.user.profile.main_character.portrait_url_32,
-            } for ownership in ownerships.select_related('character', 'user__profile__main_character').distinct()
+                'char_status': 'Main' if ownership.character == ownership.user.profile.main_character else 'Alt',
+                'char_tooltip': ownership.user.profile.main_character.character_name if ownership.character != ownership.user.profile.main_character else ', '.join(ownership.user.character_ownerships.exclude(character=ownership.character).values_list('character__character_name', flat=True))
+            } for ownership in ownerships.select_related('character', 'user__profile__main_character').prefetch_related('user__character_ownerships__character').distinct()
         ],
     })
 
@@ -222,8 +243,6 @@ def add_entry(request, rotation_id, entry_id=None):
 
                 EntryCharacter.objects.bulk_create(to_add)
 
-                entry.update_share_totals()
-
             messages.success(request, 'Entry added successfully')
 
             return redirect('allianceauth_pve:rotation_view', rotation_id)
@@ -299,7 +318,6 @@ def create_rotation(request):
             rotation = rotation_form.save()
 
             messages.success(request, "Rotation created successfully")
-
             return redirect('allianceauth_pve:rotation_view', rotation.pk)
     else:
         rotation_form = NewRotationForm()
